<?php
$TRANSLATIONS = array(
"Unable to load list from App Store" => "Nemogićnost učitavanja liste sa Apps Stora",
"Authentication error" => "Greška kod autorizacije",
"Email saved" => "Email spremljen",
"Invalid email" => "Neispravan email",
"Language changed" => "Jezik promijenjen",
"Invalid request" => "Neispravan zahtjev",
"Disable" => "Isključi",
"Enable" => "Uključi",
"Error" => "Greška",
"Saving..." => "Spremanje...",
"deleted" => "izbrisano",
"undo" => "vrati",
"Groups" => "Grupe",
"Group Admin" => "Grupa Admin",
"Delete" => "Obriši",
"__language_name__" => "__ime_jezika__",
"Cron" => "Cron",
"Log" => "dnevnik",
"More" => "više",
"Add your App" => "Dodajte vašu aplikaciju",
"Select an App" => "Odaberite Aplikaciju",
"See application page at apps.owncloud.com" => "Pogledajte stranicu s aplikacijama na apps.owncloud.com",
"Password" => "Lozinka",
"Unable to change your password" => "Nemoguće promijeniti lozinku",
"Current password" => "Trenutna lozinka",
"New password" => "Nova lozinka",
"Change password" => "Izmjena lozinke",
"Email" => "e-mail adresa",
"Your email address" => "Vaša e-mail adresa",
"Fill in an email address to enable password recovery" => "Ispunite vase e-mail adresa kako bi se omogućilo oporavak lozinke",
"Language" => "Jezik",
"Help translate" => "Pomoć prevesti",
"Create" => "Izradi",
"Other" => "ostali",
"Username" => "Korisničko ime"
);
$PLURAL_FORMS = "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;";
